package com.supwisdom.dlpay.system.controller;

import com.supwisdom.dlpay.api.bean.JsonResult;
import com.supwisdom.dlpay.framework.domain.TShop;
import com.supwisdom.dlpay.system.service.ShopDataService;
import com.supwisdom.dlpay.util.WebCheckException;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.ResponseBody;

@Controller
public class ShopController {
  @Autowired
  private ShopDataService shopDataService;

  @GetMapping("/shop/index")
  public String shopView() {
    return "system/shop/index";
  }

  @GetMapping("/shop/shoptree")
  @PreAuthorize("hasPermission('/shop/index','')")
  @ResponseBody
  public JsonResult shopTreeData(){
    return JsonResult.ok("OK").put("data", shopDataService.getAllShopNodes());
  }

  @PostMapping("/shop/deleteshop")
  @PreAuthorize("hasPermission('/shop/deleteshop','')")
  @ResponseBody
  public JsonResult deleteShop(@RequestParam("shopid") Integer shopid) {
    TShop shop = shopDataService.getShopByShopid(shopid);
    if(null==shop){
      return JsonResult.error("商户不存在，请重新查询");  //商户不存在，请重新查询
    }

    try{
      if(shopDataService.deleteShop(shop)){
        return JsonResult.ok("删除成功");
      }else{
        return JsonResult.error("删除失败");
      }
    }catch (WebCheckException ex){
      return JsonResult.error(ex.getMessage());
    }catch (Exception e){
      return JsonResult.error("系统处理异常").put("exception", e);
    }
  }
}
